/* gtk-knocker version 0.3.0
 * Release date: 1 August 2001
 *
 * Project homepage: http://knocker.sourceforge.net
 *
 * Copyright 2001 Gabriele Giorgetti <g.gabriele@europe.com>
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "gtk_support.h"

#include "dialogs.h"


char SPLASH_NOTES[]=
"WARNING: this version of gtk-knocker is still in a early development stage and so it is to be considered unstable.

For a stable and easy to use portscanner I suggest you to download the console version of knocker that is
available at: http://knocker.sourceforge.net

If you want to contribute or help with development of this software contact me at <g.gabriele@europe.com>.
";

GtkWidget* create_dialog_splash (const char *title, const char *text)
{
  GtkWidget *splash_dialog;
  GtkWidget *dialog_vbox;
  GtkWidget *body_table;
  GtkWidget *pixmap;
  GtkWidget *netoes_scrolledwindow;
  GtkWidget *notes_text;
  GtkWidget *welcome_label;
  GtkWidget *dialog_action_area1;
  GtkWidget *close_button;

  splash_dialog = gtk_dialog_new ();
  gtk_object_set_data (GTK_OBJECT (splash_dialog), "splash_dialog", splash_dialog);
  gtk_window_set_title (GTK_WINDOW (splash_dialog), title);
  gtk_window_set_position (GTK_WINDOW (splash_dialog), GTK_WIN_POS_CENTER);
  gtk_window_set_default_size (GTK_WINDOW (splash_dialog), 565, 270);

  dialog_vbox = GTK_DIALOG (splash_dialog)->vbox;
  gtk_object_set_data (GTK_OBJECT (splash_dialog), "dialog_vbox", dialog_vbox);
  gtk_widget_show (dialog_vbox);

  body_table = gtk_table_new (3, 1, FALSE);
  gtk_widget_ref (body_table);
  gtk_object_set_data_full (GTK_OBJECT (splash_dialog), "body_table", body_table,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (body_table);
  gtk_box_pack_start (GTK_BOX (dialog_vbox), body_table, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (body_table), 5);

  pixmap = create_pixmap (splash_dialog, "knocker.xpm");
  gtk_widget_ref (pixmap);
  gtk_object_set_data_full (GTK_OBJECT (splash_dialog), "pixmap", pixmap,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (pixmap);
  gtk_table_attach (GTK_TABLE (body_table), pixmap, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  netoes_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_ref (netoes_scrolledwindow);
  gtk_object_set_data_full (GTK_OBJECT (splash_dialog), "netoes_scrolledwindow", netoes_scrolledwindow,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (netoes_scrolledwindow);
  gtk_table_attach (GTK_TABLE (body_table), netoes_scrolledwindow, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (netoes_scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  notes_text = gtk_text_new (NULL, NULL);
  gtk_widget_ref (notes_text);
  gtk_object_set_data_full (GTK_OBJECT (splash_dialog), "notes_text", notes_text,
                            (GtkDestroyNotify) gtk_widget_unref);

  gtk_widget_show (notes_text);
  gtk_container_add (GTK_CONTAINER (netoes_scrolledwindow), notes_text);

  welcome_label = gtk_label_new ("Welcome to gtk-knocker");
  gtk_widget_ref (welcome_label);
  gtk_object_set_data_full (GTK_OBJECT (splash_dialog), "welcome_label", welcome_label,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (welcome_label);
  gtk_table_attach (GTK_TABLE (body_table), welcome_label, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (welcome_label), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (welcome_label), 0, 8);

  dialog_action_area1 = GTK_DIALOG (splash_dialog)->action_area;
  gtk_object_set_data (GTK_OBJECT (splash_dialog), "dialog_action_area1", dialog_action_area1);
  gtk_widget_show (dialog_action_area1);
  gtk_container_set_border_width (GTK_CONTAINER (dialog_action_area1), 10);

  close_button = gtk_button_new_with_label ("         OK         ");
  gtk_widget_ref (close_button);
  gtk_object_set_data_full (GTK_OBJECT (splash_dialog), "close_button", close_button,
                            (GtkDestroyNotify) gtk_widget_unref);

  /* Add on click event that close the dialog*/
  gtk_signal_connect_object (GTK_OBJECT (close_button), "clicked",
   			       GTK_SIGNAL_FUNC (gtk_widget_destroy),
   			       GTK_OBJECT (splash_dialog));

  gtk_widget_show (close_button);
  gtk_box_pack_start (GTK_BOX (dialog_action_area1), close_button, FALSE, FALSE, 0);


  /* Insert the license in the text */
  gtk_text_insert(GTK_TEXT (notes_text), NULL, NULL, NULL, text, -1);

  return splash_dialog;
}



GtkWidget* create_dialog_MODAL_OK (const char *title, const char *text)
{
  GtkWidget *dialog;
  GtkWidget *dialog_vbox;
  GtkWidget *text_label;
  GtkWidget *dialog_action_area;
  GtkWidget *close_button;

  dialog = gtk_dialog_new ();
  gtk_object_set_data (GTK_OBJECT (dialog), "dialog", dialog);
  gtk_window_set_title (GTK_WINDOW (dialog), title);
  GTK_WINDOW (dialog)->type = GTK_WINDOW_DIALOG;
  gtk_window_set_default_size (GTK_WINDOW (dialog), 300, 140);
  gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
  //gtk_window_set_policy (GTK_WINDOW (dialog), TRUE, TRUE, FALSE);

  dialog_vbox = GTK_DIALOG (dialog)->vbox;
  gtk_object_set_data (GTK_OBJECT (dialog), "dialog_vbox", dialog_vbox);
  gtk_widget_show (dialog_vbox);

  text_label = gtk_label_new (text);
  gtk_widget_ref (text_label);
  gtk_object_set_data_full (GTK_OBJECT (dialog), "text_label", text_label,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (text_label);
  gtk_box_pack_start (GTK_BOX (dialog_vbox), text_label, TRUE, TRUE, 0);

  dialog_action_area = GTK_DIALOG (dialog)->action_area;
  gtk_object_set_data (GTK_OBJECT (dialog), "dialog_action_area", dialog_action_area);
  gtk_widget_show (dialog_action_area);
  gtk_container_set_border_width (GTK_CONTAINER (dialog_action_area), 10);

  close_button = gtk_button_new_with_label ("         OK         ");
  gtk_widget_ref (close_button);
  gtk_object_set_data_full (GTK_OBJECT (dialog), "close_button", close_button,
                            (GtkDestroyNotify) gtk_widget_unref);

  /* Add on click event that close the dialog*/
  gtk_signal_connect_object (GTK_OBJECT (close_button), "clicked",
   			       GTK_SIGNAL_FUNC (gtk_widget_destroy),
   			       GTK_OBJECT (dialog));


  gtk_widget_show (close_button);
  gtk_box_pack_start (GTK_BOX (dialog_action_area), close_button, FALSE, FALSE, 0);

  return dialog;
}


void show_dialog_splash ( void )
{
     GtkWidget *dialog;

     dialog =  create_dialog_splash("Welcome to gtk-knocker 0.3.0", SPLASH_NOTES);

     gtk_widget_show (dialog);
}


void show_dialog_MODAL_OK (const char *title, const char *text)
{
     GtkWidget *dialog;

     dialog =  create_dialog_MODAL_OK (title, text);

     gtk_widget_show (dialog);
}

