/* gtk-knocker version 0.3.0
 * Release date: 1 August 2001
 *
 * Project homepage: http://knocker.sourceforge.net
 *
 * Copyright 2001 Gabriele Giorgetti <g.gabriele@europe.com>
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdlib.h>


#include "gtk-knocker.h"
#include "knocker_core.h"
#include "gtk_support.h"

#include "main_win.h"
#include "about_win.h"
#include "dialogs.h"




/* COMMAND LINE ARGUMENTS DEFINITION  */
/* ********************************** */
#define HELP_SHORT_OPT    "-h"
#define HELP_LONG_OPT     "--help"

#define VERSION_SHORT_OPT "-v"
#define VERSION_LONG_OPT  "--version"
/* ********************************** */


void print_version_info (void)
{
  fprintf (stdout, "%s %s (%s)\n", PACKAGE, VERSION, RELEASE_DATE);
  fprintf (stdout, "\n");
  fprintf (stdout, "Written by Gabriele Giorgetti <%s>\n", AUTHOR_EMAIL);
  fprintf (stdout, "Copyright (C) 2000, 2001 Gabriele Giorgetti\n");
  fprintf (stdout, "\n");
  fprintf (stdout, "This software is released under the GNU GPL\n");
  fprintf (stdout, "\n");
  fprintf (stdout, "%s can be found at %s\n", PACKAGE, KNOCKER_HOMEPAGE);
}


void print_help_info (void)
{
  fprintf (stdout, "%s, the net portscanner. Version %s (%s)\n", PACKAGE, VERSION, RELEASE_DATE);
  fprintf (stdout, "\n");
  fprintf (stdout, "Usage: %s\n", PACKAGE);
  fprintf (stdout, "\n");
  fprintf (stdout, "      %s,  %s             display this help and exit\n", HELP_SHORT_OPT, HELP_LONG_OPT);
  fprintf (stdout, "      %s,  %s          output version information and exit\n", VERSION_SHORT_OPT, VERSION_LONG_OPT);
  fprintf (stdout, "\n");
  fprintf (stdout, "SEE THE MAN PAGE FOR MORE DESCRIPTIONS, AND EXAMPLES\n");
  fprintf (stdout, "Report bugs to <%s>.\n", AUTHOR_EMAIL);
}



int parse_args (int argc, char *argv[])
{
  int i;

  for (i = 1; i <= argc - 1; i++)
    {
      if((!strcmp (argv[i], VERSION_SHORT_OPT))
         || (!strcmp (argv[i], VERSION_LONG_OPT)))
	{
	  print_version_info ();
	  exit (0);
	}
      else if((!strcmp (argv[i], HELP_SHORT_OPT))
         || (!strcmp (argv[i], HELP_LONG_OPT)))
        {
	  print_help_info();
	  exit(0);
	}

    }				/* end of for loop */

  return 0;
}


void start_gtk_knocker_click (GtkWidget *window)
{
   gtk_timeout_add (0, gtk_knocker_portscan, window);

}

void stop_gtk_knocker_click ( void )
{
  show_dialog_MODAL_OK ("gtk-knocker: feature not implemented", "This feature is not yet implemented.");
}


gint gtk_knocker_portscan ( GtkWidget *window )
{
  GtkWidget *host_entry;
  GtkWidget *startport_spinbutton;
  GtkWidget *endport_spinbutton;  
  GtkWidget *results_clist;

  gchar *host;

  gint port, startport, endport;

  char *service;
  char *portstr;
  char *ipstr;

  char *clist_row[2][2];

  ipstr   = (char *) malloc(40);
  service = (char *) malloc(255);
  portstr = (char *) malloc(20);

  /* get all the needed widgets from the window */
  host_entry  		= lookup_widget (window,  "host_entry");
  startport_spinbutton  = lookup_widget (window,  "startport_spinbutton");
  endport_spinbutton    = lookup_widget (window,  "endport_spinbutton");
  results_clist         = lookup_widget (window,  "results_clist");
  
  /* clear the content of the results clist */    
  gtk_clist_clear(GTK_CLIST (results_clist));
  
  /* returns the text into the entry */
  host = gtk_entry_get_text(GTK_ENTRY(host_entry));
  
  /* returns the port numbers */
  startport = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON (startport_spinbutton));
  endport   = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON (endport_spinbutton));

  if (knocker_get_ip_by_hostname (ipstr, host) != 0 )
    {
       char dialog_title[]="Error: cannot resolve hostname";
       char dialog_text[255];

       sprintf(dialog_text, "Connot resolve the hostname: %s", host);

      /* couldn't resolve the host ip address */
      /* code to handle error, to be inserted */

      show_dialog_MODAL_OK (dialog_title, dialog_text);

      return 0;
    }


  if( (startport == 0) && (endport == 0) )
    {
       for (port = 0; port <= KNOCKER_DEFAULT_PORT_RANGE; port++)
         {
            if (knocker_portscan_by_hostname (host, port) == PORT_IS_OPEN)
              {
                 sprintf(portstr, "%d", port);
		 knocker_get_service_by_port (service, port);

		 clist_row[0][0] = ipstr;
                 clist_row[0][1] = portstr;
                 clist_row[0][2] = service;
                 gtk_clist_append(GTK_CLIST (results_clist),  clist_row[0]);
              }
         }
    }
  else if (startport > endport)
    {
       for (port = startport; port >= endport; port--)
         {
            if (knocker_portscan_by_hostname (host, port) == PORT_IS_OPEN)
              {
                 sprintf(portstr, "%d", port);
		 knocker_get_service_by_port (service, port);

		 clist_row[0][0] = ipstr;
                 clist_row[0][1] = portstr;
                 clist_row[0][2] = service;
                 gtk_clist_append(GTK_CLIST (results_clist),  clist_row[0]);
              }
         }
    }
  else if (startport < endport )
    {
       for (port = startport; port <= endport; port++)
         {
            if (knocker_portscan_by_hostname (host, port) == PORT_IS_OPEN)
              {
                sprintf(portstr, "%d", port);
		knocker_get_service_by_port (service, port);

		 clist_row[0][0] = ipstr;
                 clist_row[0][1] = portstr;
                 clist_row[0][2] = service;
                gtk_clist_append(GTK_CLIST (results_clist),  clist_row[0]);
              }
         }
    }                                           

  free(ipstr);
  free(service);
  free(portstr);

  return 0;
} 



int main (int argc, char *argv[])
{
   GtkWidget *main_window;

   parse_args(argc, argv);

   gtk_set_locale ();
   gtk_init (&argc, &argv);

   add_pixmap_directory (PACKAGE_DATA_DIR "/pixmaps");
   add_pixmap_directory (PACKAGE_SOURCE_DIR "/pixmaps");

   main_window = create_main_window ();
   gtk_widget_show (main_window);

   /* display the splash screen */
   show_dialog_splash ();
                
   gtk_main ();

   return 0;
}
                    
                    
