/* gtk-knocker version 0.3.0
 * Release date: 1 August 2001
 *
 * Project homepage: http://knocker.sourceforge.net
 *
 * Copyright 2001 Gabriele Giorgetti <g.gabriele@europe.com>
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "gtk_support.h"
#include "knocker_core.h"
#include "gtk-knocker.h"


#include "main_win.h"
#include "about_win.h"


GtkWidget* create_main_window (void)
{
  GtkWidget *main_window;
  GtkWidget *main_vbox;
  GtkWidget *menu_handlebox;
  GtkWidget *menubar;
  guint tmp_key;
  GtkWidget *menu_file;
  GtkWidget *menu_file_menu;
  GtkAccelGroup *menu_file_menu_accels;
  GtkWidget *menu_separator1;
  GtkWidget *menu_exit;
  GtkWidget *menu_help;
  GtkWidget *menu_help_menu;
  GtkAccelGroup *menu_help_menu_accels;
  GtkWidget *menu_separator2;
  GtkWidget *menu_about;
  GtkWidget *body_table;
  GtkWidget *handlebox;
  GtkWidget *hbox;
  GtkWidget *host_entry;
  GtkObject *startport_spinbutton_adj;
  GtkWidget *startport_spinbutton;
  GtkObject *endport_spinbutton_adj;
  GtkWidget *endport_spinbutton;
  GtkWidget *scan_start_button;
  GtkWidget *scan_stop_button;
  GtkWidget *scrolledwindow;
  GtkWidget *results_clist;
  GtkWidget *ipaddress_label;
  GtkWidget *openports_label;
  GtkWidget *services_label;
  GtkWidget *statusbar;
  GtkAccelGroup *accel_group;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  accel_group = gtk_accel_group_new ();

  main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);

  /* Add delete event to the window so it quits properly */
  gtk_signal_connect (GTK_OBJECT (main_window), "delete_event",
                       GTK_SIGNAL_FUNC (gtk_main_quit), NULL);


  gtk_object_set_data (GTK_OBJECT (main_window), "main_window", main_window);
  gtk_window_set_title (GTK_WINDOW (main_window), "gtk-knocker 0.3.0 - The Net Port Scanner");
  gtk_window_set_default_size (GTK_WINDOW (main_window), 350, 300);
  gtk_window_set_position (GTK_WINDOW (main_window), GTK_WIN_POS_CENTER);
  gtk_window_set_policy (GTK_WINDOW (main_window), FALSE, TRUE, TRUE);

  main_vbox = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (main_vbox);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "main_vbox", main_vbox,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (main_vbox);
  gtk_container_add (GTK_CONTAINER (main_window), main_vbox);

  menu_handlebox = gtk_handle_box_new ();
  gtk_widget_ref (menu_handlebox);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_handlebox", menu_handlebox,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_handlebox);
  gtk_box_pack_start (GTK_BOX (main_vbox), menu_handlebox, FALSE, TRUE, 0);

  menubar = gtk_menu_bar_new ();
  gtk_widget_ref (menubar);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menubar", menubar,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menubar);
  gtk_container_add (GTK_CONTAINER (menu_handlebox), menubar);

  menu_file = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_file)->child),
                                   "_File");
  gtk_widget_add_accelerator (menu_file, "activate_item", accel_group,
                              tmp_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_ref (menu_file);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_file", menu_file,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_file);
  gtk_container_add (GTK_CONTAINER (menubar), menu_file);

  menu_file_menu = gtk_menu_new ();
  gtk_widget_ref (menu_file_menu);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_file_menu", menu_file_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_file), menu_file_menu);
  menu_file_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (menu_file_menu));

  menu_separator1 = gtk_menu_item_new ();
  gtk_widget_ref (menu_separator1);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_separator1", menu_separator1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_separator1);
  gtk_container_add (GTK_CONTAINER (menu_file_menu), menu_separator1);
  gtk_widget_set_sensitive (menu_separator1, FALSE);

  menu_exit = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_exit)->child),
                                   "E_xit");
  gtk_widget_add_accelerator (menu_exit, "activate_item", menu_file_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_ref (menu_exit);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_exit", menu_exit,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_exit);
  gtk_container_add (GTK_CONTAINER (menu_file_menu), menu_exit);

  menu_help = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_help)->child),
                                   "_Help");
  gtk_widget_add_accelerator (menu_help, "activate_item", accel_group,
                              tmp_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_ref (menu_help);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_help", menu_help,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_help);
  gtk_container_add (GTK_CONTAINER (menubar), menu_help);

  menu_help_menu = gtk_menu_new ();
  gtk_widget_ref (menu_help_menu);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_help_menu", menu_help_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_help), menu_help_menu);
  menu_help_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (menu_help_menu));

  menu_separator2 = gtk_menu_item_new ();
  gtk_widget_ref (menu_separator2);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_separator2", menu_separator2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_separator2);
  gtk_container_add (GTK_CONTAINER (menu_help_menu), menu_separator2);
  gtk_widget_set_sensitive (menu_separator2, FALSE);

  menu_about = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_about)->child),
                                   "_About...");
  gtk_widget_add_accelerator (menu_about, "activate_item", menu_help_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_ref (menu_about);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_about", menu_about,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_about);
  gtk_container_add (GTK_CONTAINER (menu_help_menu), menu_about);

  body_table = gtk_table_new (2, 1, FALSE);
  gtk_widget_ref (body_table);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "body_table", body_table,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (body_table);
  gtk_box_pack_start (GTK_BOX (main_vbox), body_table, TRUE, TRUE, 0);

  handlebox = gtk_handle_box_new ();
  gtk_widget_ref (handlebox);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "handlebox", handlebox,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (handlebox);
  gtk_table_attach (GTK_TABLE (body_table), handlebox, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_container_set_border_width (GTK_CONTAINER (handlebox), 5);

  hbox = gtk_hbox_new (FALSE, 0);
  gtk_widget_ref (hbox);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox", hbox,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox);
  gtk_container_add (GTK_CONTAINER (handlebox), hbox);

  host_entry = gtk_entry_new_with_max_length (255);
  gtk_widget_ref (host_entry);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "host_entry", host_entry,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (host_entry);
  gtk_box_pack_start (GTK_BOX (hbox), host_entry, TRUE, TRUE, 5);
  gtk_tooltips_set_tip (tooltips, host_entry, "Host to portscan", NULL);
  gtk_entry_set_text (GTK_ENTRY (host_entry), "type the host to scan here");

  startport_spinbutton_adj = gtk_adjustment_new (0, 0, KNOCKER_MAX_PORT_NUMBER, 1, 10, 10);
  startport_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (startport_spinbutton_adj), 1, 0);
  gtk_widget_ref (startport_spinbutton);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "startport_spinbutton", startport_spinbutton,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (startport_spinbutton);
  gtk_box_pack_start (GTK_BOX (hbox), startport_spinbutton, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, startport_spinbutton, "port number where to start to scan from", NULL);

  endport_spinbutton_adj = gtk_adjustment_new (0, 0, KNOCKER_MAX_PORT_NUMBER , 1, 10, 10);
  endport_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (endport_spinbutton_adj), 1, 0);
  gtk_widget_ref (endport_spinbutton);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "endport_spinbutton", endport_spinbutton,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (endport_spinbutton);
  gtk_box_pack_start (GTK_BOX (hbox), endport_spinbutton, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, endport_spinbutton, "port number where to scan to", NULL);



  /* START THE SCAN BUTTON */
  scan_start_button = gtk_button_new_with_label ("   start the scan   ");
  gtk_widget_ref (scan_start_button);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scan_start_button", scan_start_button,
                            (GtkDestroyNotify) gtk_widget_unref);


  /* Add on click event to the SCAN button */
  gtk_signal_connect_object (GTK_OBJECT (scan_start_button), "clicked",
   			       GTK_SIGNAL_FUNC (start_gtk_knocker_click),
   			       GTK_OBJECT(main_window));



  gtk_widget_show (scan_start_button);
  gtk_box_pack_start (GTK_BOX (hbox), scan_start_button, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, scan_start_button, "start the scan", NULL);


  /* STOP THE SCAN BUTTON */
  scan_stop_button = gtk_button_new_with_label ("   stop the scan   ");
  gtk_widget_ref (scan_stop_button);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scan_stop_button", scan_stop_button,
                            (GtkDestroyNotify) gtk_widget_unref);


  /* Add on click event to the SCAN button */
  gtk_signal_connect_object (GTK_OBJECT (scan_stop_button), "clicked",
   			       GTK_SIGNAL_FUNC (stop_gtk_knocker_click),
   			       NULL);


  gtk_widget_show (scan_stop_button);
  gtk_box_pack_start (GTK_BOX (hbox), scan_stop_button, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, scan_stop_button, "stop the scan", NULL);




  scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_ref (scrolledwindow);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow", scrolledwindow,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow);
  gtk_table_attach (GTK_TABLE (body_table), scrolledwindow, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  results_clist = gtk_clist_new (3);
  gtk_widget_ref (results_clist);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "results_clist", results_clist,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (results_clist);
  gtk_container_add (GTK_CONTAINER (scrolledwindow), results_clist);
  gtk_clist_set_column_width (GTK_CLIST (results_clist), 0, 113);
  gtk_clist_set_column_width (GTK_CLIST (results_clist), 1, 80);
  gtk_clist_column_titles_show (GTK_CLIST (results_clist));

  ipaddress_label = gtk_label_new ("Host IP address:");
  gtk_widget_ref (ipaddress_label);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "ipaddress_label", ipaddress_label,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ipaddress_label);
  gtk_clist_set_column_widget (GTK_CLIST (results_clist), 0, ipaddress_label);

  openports_label = gtk_label_new ("Open ports:");
  gtk_widget_ref (openports_label);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "openports_label", openports_label,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (openports_label);
  gtk_clist_set_column_widget (GTK_CLIST (results_clist), 1, openports_label);

  services_label = gtk_label_new ("Service name:");
  gtk_widget_ref (services_label);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "services_label", services_label,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (services_label);
  gtk_clist_set_column_widget (GTK_CLIST (results_clist), 2, services_label);

  statusbar = gtk_statusbar_new ();
  gtk_widget_ref (statusbar);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "statusbar", statusbar,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (statusbar);
  gtk_box_pack_start (GTK_BOX (main_vbox), statusbar, FALSE, FALSE, 0);

  gtk_signal_connect (GTK_OBJECT (menu_exit), "activate",
                      GTK_SIGNAL_FUNC (on_menu_exit_click),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_about), "activate",
                      GTK_SIGNAL_FUNC (on_menu_about_click),
                      NULL);

  gtk_object_set_data (GTK_OBJECT (main_window), "tooltips", tooltips);

  gtk_window_add_accel_group (GTK_WINDOW (main_window), accel_group);

  return main_window;
}


void on_menu_exit_click (GtkMenuItem *menuitem, gpointer user_data)
{
  gtk_main_quit();
}


void on_menu_about_click (GtkMenuItem *menuitem, gpointer user_data)
{
  GtkWidget *about_window;

  about_window = create_about_window ();

  gtk_widget_show (about_window);
}
